@@ -3,7 +3,7 @@ from __future__ import annotations
 from datetime import datetime
 from typing import Dict, List, Optional
 
-from pydantic import BaseModel
+from pydantic import BaseModel, Field
 
 
 class Error(BaseModel):
@@ -29,5 +29,5 @@ class Function(BaseModel):
 class Session(BaseModel):
 
     functions: List[Function]
-    timestamp: datetime
     metadata: Optional[Dict[str, str]] = None
+    timestamp: datetime = Field(default_factory=datetime.utcnow)
